@@ -4,5 +4,5 @@ dataset_library.py
 
 
 from ldimbenchmark.datasets.library import DatasetLibrary, DATASETS
-from ldimbenchmark.datasets.classes import Dataset, LoadedDataset
+from ldimbenchmark.datasets.classes import Dataset
 from ldimbenchmark.datasets.derivation import DatasetDerivator
